@@ -4,6 +4,7 @@ use crate::common::{is_valid_timestamp, USECONDS_PER_DAY};
 use crate::error::{Error, Result};
 use crate::format::{Formatter, LazyFormat, NaiveDateTime};
 use crate::{Date, DateTime, IntervalDT, IntervalYM, Time};
+use chrono::{Datelike, Local};
 use std::cmp::Ordering;
 use std::convert::TryFrom;
 use std::fmt::Display;
@@ -245,6 +246,19 @@ impl From<Date> for Timestamp {
     }
 }
 
+impl TryFrom<Time> for Timestamp {
+    type Error = Error;
+
+    #[inline]
+    fn try_from(time: Time) -> Result<Self> {
+        let now = Local::now().naive_local();
+        Ok(Timestamp::new(
+            Date::try_from_ymd(now.year(), now.month(), 1)?,
+            time,
+        ))
+    }
+}
+
 impl DateTime for Timestamp {
     #[inline]
     fn year(&self) -> Option<i32> {
@@ -408,6 +422,11 @@ mod tests {
                     Timestamp::parse("PM 11-9999-59.999999 12-59-31", "PM HH-YYYY-MI.FF MM-SS-DD")
                         .unwrap();
                 assert_eq!(ts2, ts);
+                assert!(Timestamp::parse(
+                    "P.M. 11-9999-59.999999 12-59-31",
+                    "PM HH-YYYY-MI.FF MM-SS-DD"
+                )
+                .is_err());
 
                 let ts2 =
                     Timestamp::parse("23-9999-59.999999 12 59 31", "HH24-YYYY-MI.FF MM SS DD")
